@@ -15,8 +15,8 @@ use List::Util;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 
-
-our $VERSION     = version->new('0.0.5');
+our $VERSION    = version->new('0.0.6');
+$ENV{W3C_SOAP_NAME_STYLE} ||= 'perl';
 
 has node => (
     is       => 'rw',
@@ -76,6 +76,9 @@ sub perl_name {
     my ($self) = @_;
     my $name = $self->name;
     return if !$name;
+
+    return $name if $ENV{W3C_SOAP_NAME_STYLE} eq 'original';
+
     $name =~ s/ (?<= [^A-Z_] ) ([A-Z]) /_$1/gxms;
     return lc $name;
 }
@@ -90,7 +93,7 @@ W3C::SOAP::Document::Node - The super class for document nodes
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::Document::Node version 0.0.5.
+This documentation refers to W3C::SOAP::Document::Node version 0.0.6.
 
 =head1 SYNOPSIS
 
