@@ -18,7 +18,7 @@ use English qw/ -no_match_vars /;
 
 extends 'Moose::Meta::Method';
 
-our $VERSION     = version->new('0.0.5');
+our $VERSION     = version->new('0.0.6');
 
 has wsdl_operation => (
     is        => 'rw',
@@ -48,6 +48,11 @@ has out_attribute => (
     isa       => 'Str',
     predicate => 'has_out_attribute',
 );
+has faults => (
+    is        => 'rw',
+    isa       => 'ArrayRef[HashRef]',
+    predicate => 'has_faults',
+);
 has security => (
     is        => 'rw',
     isa       => 'Str',
@@ -65,7 +70,7 @@ W3C::SOAP::WSDL::Meta::Method - <One-line description of module's purpose>
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WSDL::Meta::Method version 0.0.5.
+This documentation refers to W3C::SOAP::WSDL::Meta::Method version 0.0.6.
 
 
 =head1 SYNOPSIS
