@@ -25,7 +25,7 @@ Moose::Exporter->setup_import_methods(
     as_is => ['load_wsdl'],
 );
 
-our $VERSION     = version->new('0.0.5');
+our $VERSION     = version->new('0.0.6');
 
 has document => (
     is       => 'rw',
@@ -170,6 +170,13 @@ sub dynamic_classes {
             for my $operation (@{ $port->binding->operations }) {
                 my $in_element  = eval { $operation->port_type->inputs->[0]->message->element };
                 my $out_element = eval { $operation->port_type->outputs->[0]->message->element };
+                my @faults = eval {
+                    map {{
+                        class => $_->message->element->module,
+                        name  => $_->message->element->perl_name,
+                    }}
+                    @{ $operation->port_type->faults }
+                };
 
                 $method{ $operation->perl_name } = W3C::SOAP::WSDL::Meta::Method->wrap(
                     body           => sub { shift->_request($operation->perl_name => @_) },
@@ -180,7 +187,17 @@ sub dynamic_classes {
                     $in_element  ? ( in_attribute  => $in_element->perl_name  ) : (),
                     $out_element ? ( out_class     => $out_element->module    ) : (),
                     $out_element ? ( out_attribute => $out_element->perl_name ) : (),
+                    @faults ? ( faults => \@faults ) : (),
                 );
+
+                if ( $ENV{W3C_SOAP_NAME_STYLE} eq 'both' && $operation->name ne $operation->perl_name ) {
+                    my $name = $operation->perl_name;
+                    $method{ $operation->name } = Moose::Meta::Method->wrap(
+                        body         => sub { shift->$name(@_) },
+                        package_name => $class_name,
+                        name         => $operation->name,
+                    );
+                }
             }
         }
     }
@@ -210,7 +227,7 @@ W3C::SOAP::WSDL::Parser - Module to create Moose objects from a WSDL
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WSDL::Parser version 0.0.5.
+This documentation refers to W3C::SOAP::WSDL::Parser version 0.0.6.
 
 =head1 SYNOPSIS
 
