@@ -26,7 +26,7 @@ Moose::Exporter->setup_import_methods(
     as_is => ['load_xsd'],
 );
 
-our $VERSION     = version->new('0.0.5');
+our $VERSION     = version->new('0.0.6');
 
 subtype xsd_documents =>
     as 'ArrayRef[W3C::SOAP::XSD::Document]';
@@ -430,6 +430,13 @@ sub element_attributes {
         @extra,
     );
 
+    if ( $ENV{W3C_SOAP_NAME_STYLE} eq 'both' && $element->name ne $element->perl_name ) {
+        my $name = $element->perl_name;
+        $class->add_method(
+            $element->name => sub { shift->$name(@_) }
+        );
+    }
+
     return;
 }
 1;
@@ -442,7 +449,7 @@ W3C::SOAP::XSD::Parser - Parse an W3C::SOAP::XSD::Document and create perl modul
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD::Parser version 0.0.5.
+This documentation refers to W3C::SOAP::XSD::Parser version 0.0.6.
 
 =head1 SYNOPSIS
 
